diag.qr: Diagnostics for Quantile Regression Using Asymmetric Laplace Distribution
Description
Return case-deletion estimating the parameters in a quantile regression
Usage
diag.qr(y,x,tau,theta)
Arguments
y
vector of responses
x
the design matrix
tau
the quantile to be estimated, this is generally a number strictly between 0 and 1.
theta
parameter estimated
Value
References
[1] Koenker, R. W. (2005). Quantile Regression, Cambridge U. Press.
[2] Yu, K. & Moyeed, R. (2001). Bayesian quantile regression. Statistics & Probability Letters, 54 (4), 437 to 447.
[3] Kotz, S., Kozubowski, T. & Podgorski, K. (2001). The laplace distribution and generalizations: A revisit with applications to communications, economics, engineering, and finance. Number 183. Birkhauser.